<?php

declare(strict_types=1);

namespace Dedi\SyliusQuotePlugin\Processor\Order;

use Dedi\SyliusQuotePlugin\Model\OrderInterface;
use Sylius\Component\Core\Model\AdjustmentInterface;
use Sylius\Component\Order\Factory\AdjustmentFactoryInterface;
use Sylius\Component\Order\Model\OrderInterface as BaseOrderInterface;
use Sylius\Component\Order\Processor\OrderProcessorInterface;
use Symfony\Contracts\Translation\TranslatorInterface;

class QuoteTotalOrderProcessor implements OrderProcessorInterface
{
    private AdjustmentFactoryInterface $adjustmentFactory;

    private TranslatorInterface $translator;

    public function __construct(AdjustmentFactoryInterface $adjustmentFactory, TranslatorInterface $translator)
    {
        $this->adjustmentFactory = $adjustmentFactory;
        $this->translator = $translator;
    }

    public function process(BaseOrderInterface $order): void
    {
        if (!$order instanceof OrderInterface || ($quote = $order->getQuote()) === null) {
            return;
        }

        $order->addAdjustment($this->adjustmentFactory->createWithData(
            AdjustmentInterface::ORDER_PROMOTION_ADJUSTMENT,
            $this->translator->trans('dedi_quote.ui.quote_total_adjustment', ['%number%' => $quote->getNumber()]),
            $quote->getTotal() - $order->getTotal(),
            false
        ));
    }
}
